aboutsummaryrefslogtreecommitdiff
path: root/include/sqfs/error.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/sqfs/error.h')
-rw-r--r--include/sqfs/error.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/sqfs/error.h b/include/sqfs/error.h
index 055e98f..e13d204 100644
--- a/include/sqfs/error.h
+++ b/include/sqfs/error.h
@@ -23,11 +23,11 @@
/**
* @file error.h
*
* @brief Contains the @ref E_SQFS_ERROR enumerator.
*/
/**
- * @enum E_SQFS_ERROR
+ * @enum SQFS_ERROR
*
* @brief Error codes that can be returned by various libsquashfs functions.
*/
@@ -145,6 +145,6 @@ typedef enum {
* performed and the object can still be used.
*/
SQFS_ERROR_SEQUENCE = -17,
-} E_SQFS_ERROR;
+} SQFS_ERROR;
#endif /* SQFS_ERROR_H */
@@ -23,11 +23,11 @@
* @file error.h
*
- * @brief Contains the @ref E_SQFS_ERROR enumerator.
+ * @brief Contains the @ref SQFS_ERROR enumerator.
*/
/**